@@ -80,7 +80,7 @@ def encode_multipart_formdata(fields, files):
     content_type = 'multipart/form-data; boundary=%s' % BOUNDARY
     return content_type, body
 
-class Wiki():
+class Wiki(object):
     ''' Class for performing general requests to the API
     and storing session info.
     '''
@@ -88,6 +88,14 @@ class Wiki():
     namespaces_names = None # map from id to localised name
     namespaces_ids = None # map from canonical name to id
 
+    def get_namespace_id(self, ns_name):
+        ''' Get namespace id by localised or canonical name.
+        If namespace is not found - return None '''
+        for i, name in self.namespaces_names.items():
+            if name == ns_name:
+                return i
+        return namespaces_ids.get(ns_name)
+
     def __init__(self, endpoint=None, throttle=1,
         disable_ssl_certificate_validation=True
     ):
@@ -484,6 +492,13 @@ class Wiki():
 
         self.init_namespaces()
 
+    def set_default_namespaces(self):
+        ''' For testing or some other purposes, without request '''
+        names = ['User', 'User talk', 'Category', 'File']
+        self.namespaces_names = {i: name for i, name in enumerate(names)}
+        self.namespaces_ids = {name: i for i, name in enumerate(names)}
+        self.init_namespaces()
+
     def init_namespaces(self):
         ''' Set some constants '''
         def ns_name(canonical):
@@ -508,7 +523,7 @@ class Wiki():
         return 'Wiki("%s")' % self.endpoint
 
 
-class Change:
+class Change(object):
     def __init__(self, wiki, data):
         self.wiki = wiki
         self.type = data.get('type')
@@ -519,7 +534,7 @@ class Change:
     def __str__(self):
         return '{}.change({})'.format(self.page, self.time)
 
-class Page:
+class Page(object):
     def __init__(self, wiki, title):
         self.wiki = wiki
         self.title = title
@@ -795,7 +810,7 @@ class File(Page):
         with open(to_file, 'wb') as f:
             f.write(content)
 
-class User():
+class User(object):
     def __init__(self, wiki, name):
         self.wiki = wiki
         self.name = name
